==> am_mod_grp_0_1.zip: am_mod_grp_0_1/components/grp/template/barnraiser_01/forum_subject_edit.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<script language="JavaScript" src="<?php echo $template_path_core;?>/js/imageHandling.js" type="text/javascript"></script>

<script type="text/javascript" src="speller/spellChecker.js"></script>
<script type="text/javascript">
	function openSpellChecker() {
		var speller = new spellChecker();
		speller.spellCheckAll();
	}
</script>


<form action="index.php?amn=grp_forum_subject_edit" method="post" name="frm" id="id_frm">
<input type="hidden" name="group_id" value="<?php echo $group['group_id'];?>" />
<input type="hidden" name="topic_id" value="<?php echo $topic['topic_id'];?>" />
<input type="hidden" name="subject_id" value="<?php if (isset($subject['subject_id'])) { echo $subject['subject_id'];}?>" />

<?php
if (isset($display) && $display == "edit_subject") {
?>
<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_group_edit'];?><br />
	</div>
	
	<div class="box_mid">
		<div class="content">
			<table cellspacing="0" cellpadding="0" border="0">
				<tr>
					<td valign="top" width="50%">
						<p>
							<label for="id_subject_title"><?php echo $lang['txt_title'];?></label>
							<input id="id_subject_title" class="input" type="text" name="subject_title" size="24" value="<?php if (isset($subject['subject_title'])) { echo $subject['subject_title'];}?>" />
							&nbsp;<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
							<br />
						</p>
						
						<p>
							<label for="id_subject_synopsis"><?php echo $lang['txt_synopsis'];?></label>
							<textarea id="id_subject_synopsis" name="subject_synopsis" cols="22" rows="2"><?php if (isset($subject['subject_synopsis'])) { echo $subject['subject_synopsis'];}?></textarea>
							<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
							<br />
						</p>
						
						<?php
						if (isset($polls)) {
						?>
						<p>
							<label for="id_poll_id"><?php echo $lang['txt_polls'];?></label>
							<select style="width:150px;" id="id_poll_id" name="poll_id">
								<option value="0" selected="selected"><?php echo $lang['txt_none'];?></option>
								<?php
								foreach($polls as $key => $i):
								
								$selected = "";
								if (isset($subject['poll_id']) && $subject['poll_id'] == $i['poll_id']) {
									$selected = "selected=\"selected\"";
								}
								?>
								<option value="<?php echo $i['poll_id'];?>" <?php echo $selected;?>><?php echo $i['poll_question'];?></option>
								<?php
								endforeach;
								?>
							</select>
						</p>
						<?php }?>
					</td>
					<td>
						<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" width="20" height="1" /><br />
					</td>
					<td valign="top" width="50%">
						<?php
						if (isset($images)) {
						?>
						<table cellspacing="0" cellpadding="2" border="0" width="100%">
							<tr>
								<td valign="top">
									<label for="frm_file" style="width:105px;"><?php echo $lang['txt_image']; ?></label><br />	
								</td>
								<td valign="top" width="100%">
									<select style="width:150px;" id="id_file_id" size="3" name="file_id" onChange='javascript:setimg(this)'>
										<option value="0" selected="selected"><?php echo $lang['txt_none'];?></option>
										<?php
										$img_divs = "";
										foreach($images as $key => $i):
										$display_state = "none";
										$selected = "";
										if (isset($subject['file_id']) && $subject['file_id'] == $i['file_id']) {
											$selected = "selected=\"selected\"";
											$display_state = "block";
										}
										?>
										<option value="<?php echo $i['file_id'];?>" <?php echo $selected;?>><?php echo $i['file_save_name'];?></option>
										<?php
										$img_divs .= "<div style=\"display:" . $display_state . ";\" id=img" . $i['file_id'] . "><img src=\"get_file.php?file=" . $i['file_md5_name_view'] . "&amp;type=" . $i['type'] . "&amp;directory=" . $i['directory'] . "\" border=\"0\" class=\"picture\" /></div>";
										endforeach;
										?>
									</select>
								</td>
								<td valign="top" align="right">
									<?php echo $img_divs;?>
								</td>	
							</tr>
						</table>
						<?php }?>
						
						<p>
							<label for="id_subject_locked"><?php echo $lang['txt_locked'];?></label>
							<input type="checkbox" id="id_subject_locked" name="subject_locked" /><br />			
						</p>
						
						<p>
							<label for="id_subject_sticky"><?php echo $lang['txt_sticky'];?></label>
							<input type="checkbox" id="id_subject_sticky" name="subject_sticky" /><br />			
						</p>
					</td>
				</tr>
			</table>
			
			<hr />
			
			<p>
				<label for="id_subject_body"><?php echo $lang['txt_body'];?></label>
				<textarea id="id_subject_body" name="subject_body" cols="62" rows="4"><?php if (isset($subject['subject_body'])) { echo $subject['subject_body'];}?></textarea>
				<br />
			</p>

			<hr />
						
			<p align="right">
				<input type="submit" name="preview_subject" id="id_sub_preview" class="input_submit" value="<?php echo $lang['sub_preview']; ?>" />
				<?php
				if (isset($allow_spellcheck)) {
				?>
				<input type="button" class="input_submit" value="<?php echo $lang['sub_check_spelling'];?>" onClick="openSpellChecker();" />
				<?php }?>
				
				<input type="submit" name="update_subject" id="id_sub_update" class="input_submit" value="<?php echo $lang['sub_update'];?>" />
				<br />
			</p>
			
			<?php
			if (isset($subject['display_subject_body'])) {
			?>
			<p></p>
				<?php echo $subject['display_subject_body'];?><br />
			</p>
			<?php }?>
		</div>
	</div>
</div>


<?php
}
elseif (isset($display) && $display == "select_subject") {
?>
<input type="hidden" name="subject_title" value="<?php if (isset($subject['subject_title'])) { echo $subject['subject_title'];}?>" />
<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_choose_subject'];?><br />
	</div>
		
	<div class="box_mid">
		<div class="content">
			<?php
			if (isset($subjects)) {
			?>
			<table cellspacing="2" cellpadding="0" border="0" width="100%">
				<tr>
					<td valign="top">
						<br />
					</td>
					<td align="right">
						<input type="checkbox" onClick="checkFormBoxes(this);" /><br />
					</td>
				</tr>
				<?php
				foreach ($subjects as $key => $i):
				?>
				<tr>
					<td valign="top">
						<b><?php echo $i['subject_title'];?></b><br />
						<?php echo $i['subject_synopsis'];?><br />
					</td>
					<td align="right">
						<input type="checkbox" name="subject_ids[]" value="<?php echo $i['subject_id'];?>" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>
			
			<hr />
			
			<p align="right">
				<input type="submit" name="edit_subject" class="input_submit" value="<?php echo $lang['sub_edit_subject'];?>" />
				&nbsp;
				<input type="submit" name="mark_subjects" class="input_submit" value="<?php echo $lang['sub_mark'];?>" />
			</p>
		</div>
	</div>
</div>

<?php
}
else {
?>
<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_choose_subject'];?><br />
	</div>
		
	<div class="box_mid">
		<div class="content">
			<p>
				<label for="id_subject_title"><?php echo $lang['txt_title_intro'];?></label>
				<input id="id_subject_title" class="input1" type="text" name="subject_title" size="44" value="<?php if (isset($subject['subject_title'])) { echo $subject['subject_title'];}?>" />
				<br />
			</p>
			
			<hr />
			
			<p align="right">
				<input type="submit" name="search_title" class="input_submit" value="<?php echo $lang['sub_search_title'];?>" />
			</p>
		</div>
	</div>
</div>
<?php }?>

</form>

<script language="javascript">
<!--
function checkFormBoxes(id) { //task is check or uncheck
	
	var form = document.frm.elements['subject_ids[]'];
	var state = true;
	
	if (id.checked == false) {
		state = false;
	}
	
	if (form.length) {
		for (var i=0; i < form.length; i++) {
			form[i].checked = state;
		}
	}
	else {
		form.checked = state;
	}
}
//-->
</script>

==> am_mod_grp_0_3.zip: am_mod_grp_0_3/components/grp/template/barnraiser_01/forum_subject_edit.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<script language="JavaScript" src="<?php echo $template_path_core;?>/js/imageHandling.js" type="text/javascript"></script>

<script type="text/javascript" src="speller/spellChecker.js"></script>
<script type="text/javascript">
	function openSpellChecker() {
		var speller = new spellChecker();
		speller.spellCheckAll();
	}
</script>


<form action="index.php?amn=grp_forum_subject_edit" method="post" name="frm" id="id_frm">
<input type="hidden" name="group_id" value="<?php echo $group['group_id'];?>" />
<input type="hidden" name="topic_id" value="<?php echo $topic['topic_id'];?>" />
<input type="hidden" name="subject_id" value="<?php if (isset($subject['subject_id'])) { echo $subject['subject_id'];}?>" />

<?php
if (isset($display) && $display == "edit_subject") {
?>
<div class="box">
	<div class="box_top">
		<div class="content">
			<h1><?php echo $lang['hdr_group_edit'];?></h1>
		</div>
	</div>
	
	<div class="box_mid">
		<div class="content">
			<table cellspacing="0" cellpadding="0" border="0">
				<tr>
					<td valign="top" width="50%">
						<p>
							<label for="id_subject_title"><?php echo $lang['txt_title'];?></label>
							<input id="id_subject_title" class="input" type="text" name="subject_title" size="24" value="<?php if (isset($subject['subject_title'])) { echo $subject['subject_title'];}?>" />
							&nbsp;<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
							<br />
						</p>
						
						<p>
							<label for="id_subject_synopsis"><?php echo $lang['txt_synopsis'];?></label>
							<textarea id="id_subject_synopsis" name="subject_synopsis" cols="22" rows="2"><?php if (isset($subject['subject_synopsis'])) { echo $subject['subject_synopsis'];}?></textarea>
							<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
							<br />
						</p>
						
						<?php
						if (isset($polls)) {
						?>
						<p>
							<label for="id_poll_id"><?php echo $lang['txt_polls'];?></label>
							<select style="width:150px;" id="id_poll_id" name="poll_id">
								<option value="0" selected="selected"><?php echo $lang['txt_none'];?></option>
								<?php
								foreach($polls as $key => $i):
								
								$selected = "";
								if (isset($subject['poll_id']) && $subject['poll_id'] == $i['poll_id']) {
									$selected = "selected=\"selected\"";
								}
								?>
								<option value="<?php echo $i['poll_id'];?>" <?php echo $selected;?>><?php echo $i['poll_question'];?></option>
								<?php
								endforeach;
								?>
							</select>
						</p>
						<?php }?>
					</td>
					<td>
						<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" width="20" height="1" /><br />
					</td>
					<td valign="top" width="50%">
						<?php
						if (isset($images)) {
						?>
						<table cellspacing="0" cellpadding="2" border="0" width="100%">
							<tr>
								<td valign="top">
									<label for="frm_file" style="width:105px;"><?php echo $lang['txt_image']; ?></label><br />	
								</td>
								<td valign="top" width="100%">
									<select style="width:150px;" id="id_file_id" size="3" name="file_id" onChange='javascript:setimg(this)'>
										<option value="0" selected="selected"><?php echo $lang['txt_none'];?></option>
										<?php
										$img_divs = "";
										foreach($images as $key => $i):
										$display_state = "none";
										$selected = "";
										if (isset($subject['file_id']) && $subject['file_id'] == $i['file_id']) {
											$selected = "selected=\"selected\"";
											$display_state = "block";
										}
										?>
										<option value="<?php echo $i['file_id'];?>" <?php echo $selected;?>><?php echo $i['file_save_name'];?></option>
										<?php
										$img_divs .= "<div style=\"display:" . $display_state . ";\" id=img" . $i['file_id'] . "><img src=\"get_file.php?file=" . $i['file_md5_name_view'] . "&amp;type=" . $i['type'] . "&amp;directory=" . $i['directory'] . "\" border=\"0\" class=\"picture\" /></div>";
										endforeach;
										?>
									</select>
								</td>
								<td valign="top" align="right">
									<?php echo $img_divs;?>
								</td>	
							</tr>
						</table>
						<?php }?>
						
						<p>
							<label for="id_subject_locked"><?php echo $lang['txt_locked'];?></label>
							<input type="checkbox" id="id_subject_locked" name="subject_locked" /><br />			
						</p>
						
						<p>
							<label for="id_subject_sticky"><?php echo $lang['txt_sticky'];?></label>
							<input type="checkbox" id="id_subject_sticky" name="subject_sticky" /><br />			
						</p>
					</td>
				</tr>
			</table>
			
			<hr />
			
			<p>
				<label for="id_subject_body"><?php echo $lang['txt_body'];?></label>
				<textarea id="id_subject_body" name="subject_body" cols="62" rows="4"><?php if (isset($subject['subject_body'])) { echo $subject['subject_body'];}?></textarea>
				<br />
			</p>

			<hr />
						
			<p align="right">
				<input type="submit" name="preview_subject" id="id_sub_preview" class="input_submit" value="<?php echo $lang['sub_preview']; ?>" />
				<?php
				if (isset($allow_spellcheck)) {
				?>
				<input type="button" class="input_submit" value="<?php echo $lang['sub_check_spelling'];?>" onClick="openSpellChecker();" />
				<?php }?>
				
				<input type="submit" name="update_subject" id="id_sub_update" class="input_submit" value="<?php echo $lang['sub_update'];?>" />
				<br />
			</p>
			
			<?php
			if (isset($subject['display_subject_body'])) {
			?>
			<p></p>
				<?php echo $subject['display_subject_body'];?><br />
			</p>
			<?php }?>
		</div>
	</div>
</div>


<?php
}
elseif (isset($display) && $display == "select_subject") {
?>
<input type="hidden" name="subject_title" value="<?php if (isset($subject['subject_title'])) { echo $subject['subject_title'];}?>" />
<div class="box">
	<div class="box_top">
		<div class="content">
			<h1><?php echo $lang['hdr_choose_subject'];?></h1>
		</div>
	</div>
		
	<div class="box_mid">
		<div class="content">
			<?php
			if (isset($subjects)) {
			?>
			<table cellspacing="2" cellpadding="0" border="0" width="100%">
				<tr>
					<td valign="top">
						<br />
					</td>
					<td align="right">
						<input type="checkbox" onClick="checkFormBoxes(this);" /><br />
					</td>
				</tr>
				<?php
				foreach ($subjects as $key => $i):
				?>
				<tr>
					<td valign="top">
						<b><?php echo $i['subject_title'];?></b><br />
						<?php echo $i['subject_synopsis'];?><br />
					</td>
					<td align="right">
						<input type="checkbox" name="subject_ids[]" value="<?php echo $i['subject_id'];?>" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>
			
			<hr />
			
			<p align="right">
				<input type="submit" name="edit_subject" class="input_submit" value="<?php echo $lang['sub_edit_subject'];?>" />
				&nbsp;
				<input type="submit" name="mark_subjects" class="input_submit" value="<?php echo $lang['sub_mark'];?>" />
			</p>
		</div>
	</div>
</div>

<?php
}
else {
?>
<div class="box">
	<div class="box_top">
		<div class="content">
			<h1><?php echo $lang['hdr_choose_subject'];?></h1>
		</div>
	</div>
		
	<div class="box_mid">
		<div class="content">
			<p>
				<label for="id_subject_title"><?php echo $lang['txt_title_intro'];?></label>
				<input id="id_subject_title" class="input1" type="text" name="subject_title" size="44" value="<?php if (isset($subject['subject_title'])) { echo $subject['subject_title'];}?>" />
				<br />
			</p>
			
			<hr />
			
			<p align="right">
				<input type="submit" name="search_title" class="input_submit" value="<?php echo $lang['sub_search_title'];?>" />
			</p>
		</div>
	</div>
</div>
<?php }?>

</form>

<script language="javascript">
<!--
function checkFormBoxes(id) { //task is check or uncheck
	
	var form = document.frm.elements['subject_ids[]'];
	var state = true;
	
	if (id.checked == false) {
		state = false;
	}
	
	if (form.length) {
		for (var i=0; i < form.length; i++) {
			form[i].checked = state;
		}
	}
	else {
		form.checked = state;
	}
}
//-->
</script>
